{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(ext) { var root = inputs.input_filename.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_filename.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/iaintersect:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--a=",
                        "separate": false
                    },
                    "doc": "Annotation file, tsv",
                    "id": "#iaintersect.cwl/annotation_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--sam_ignorechr=",
                        "separate": false
                    },
                    "doc": "The chromosome to be ignored, string\n",
                    "id": "#iaintersect.cwl/ignore_chr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--in=",
                        "separate": false
                    },
                    "doc": "Input filename with MACS2 peak calling results, tsv",
                    "id": "#iaintersect.cwl/input_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--log=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.log');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Log filename\n",
                    "id": "#iaintersect.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--out=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.tsv');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Base output file name, tsv\n",
                    "id": "#iaintersect.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--promoter=",
                        "separate": false
                    },
                    "doc": "Promoter region around TSS, base pairs\n",
                    "id": "#iaintersect.cwl/promoter_bp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--upstream=",
                        "separate": false
                    },
                    "doc": "Upstream region before promoter, base pairs\n",
                    "id": "#iaintersect.cwl/upstream_bp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.log_filename == \"\"){\n    return default_output_filename('_iaintersect.log');\n  } else {\n    return inputs.log_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename('_iaintersect.tsv');\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/result_file"
                }
            ],
            "baseCommand": [
                "iaintersect"
            ],
            "doc": "Tool assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic)\n\n`default_output_filename` function returns output filename with sufix set as `ext` argument. Function is called when\neither `output_filename` or `log_filename` inputs are not provided.\n",
            "id": "#iaintersect.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#iaintersect-metadata.yaml",
                "http://schema.org/name": "iaintersect",
                "http://schema.org/about": "Based on BioWardrobe iaintersect (https://github.com/cincinnati-childrens-hospital/biowardrobe/tree/master/src/iaintersect) The software assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic).\n",
                "http://schema.org/url": "https://github.com/Barski-lab/iaintersect/blob/master/README.md",
                "http://schema.org/codeRepository": "https://github.com/Barski-lab/iaintersect",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.0.1",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/discussionUrl": [
                    "https://github.com/Barski-lab/iaintersect/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Barski Research Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Andrey Kartashov",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Michael Kotliar",
                                "http://schema.org/description": "Update to work with files instead of DB"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "iaintersect",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/iaintersect.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  iaintersect [options] --in=pathToFile --a=pathtoFile --out=pathToFile\n  --a                        \tTab-separated annotation file\n  --in                       \tInput filename with MACS2 peak calling results, xls\n  --log                      \tLog filename (default is ./logfile_def.log)\n  --out                      \tBase output file name\n  --promoter                 \tPromoter region around TSS in bp\n  --sam_ignorechr            \tThe chromosome to be ignored\n  --upstream                 \tUpstream region before promoter in bp\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function() { if (inputs.output_filename) { return inputs.output_filename; } return inputs.unsorted_file.location.split('/').slice(-1)[0]; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-k, --key=POS1[,POS2]\nstart a key at POS1, end it at POS2 (origin 1)\n",
                    "id": "#linux-sort.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#linux-sort.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#linux-sort.cwl/unsorted_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#linux-sort.cwl/sorted_file",
                    "outputBinding": {
                        "glob": "$(get_output_filename())"
                    }
                }
            ],
            "stdout": "$(get_output_filename())",
            "baseCommand": [
                "sort"
            ],
            "doc": "Tool sorts data from `unsorted_file` by key\n\n`default_output_filename` function returns file name identical to `unsorted_file`, if `output_filename` is not provided.\n",
            "id": "#linux-sort.cwl",
            "http://schema.org/name": "linux-sort",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/linux-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/rgt:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--a_threshold",
                        "position": 32
                    },
                    "doc": "Define the A threshold of percentile for training TMM. [default: 95]",
                    "id": "#rgt-thor.cwl/a_threshold"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 6,
                        "itemSeparator": ","
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "doc": "Alignment and index files for the first biological condition",
                    "id": "#rgt-thor.cwl/bambai_pair_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 7,
                        "itemSeparator": ","
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "doc": "Alignment and index files for the second biological condition",
                    "id": "#rgt-thor.cwl/bambai_pair_cond_2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--size",
                        "position": 27
                    },
                    "doc": "Number of bins the HMM's training set constists of. [default: 10000]",
                    "id": "#rgt-thor.cwl/bin_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--binsize",
                        "position": 21
                    },
                    "doc": "Size of underlying bins for creating the signal. [default: 100]",
                    "id": "#rgt-thor.cwl/bin_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8
                    },
                    "doc": "Chromosome length file",
                    "id": "#rgt-thor.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--deadzones",
                        "position": 14
                    },
                    "doc": "Define blacklisted genomic regions avoided for analysis",
                    "id": "#rgt-thor.cwl/deadzones_bed_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--exts",
                        "position": 17,
                        "itemSeparator": ","
                    },
                    "doc": "Read's extension size for BAM files (comma separated list for each BAM file in config file).\nIf option is not chosen, estimate extension sizes\n",
                    "id": "#rgt-thor.cwl/extension_size"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--foldchange",
                        "position": 25
                    },
                    "doc": "Fold change parameter to define training set (t_1, see paper). [default: 1.6]",
                    "id": "#rgt-thor.cwl/foldchange"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--housekeeping-genes",
                        "position": 12
                    },
                    "doc": "Define housekeeping genes (BED format) used for normalizing",
                    "id": "#rgt-thor.cwl/housekeeping_genes_bed_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--m_threshold",
                        "position": 31
                    },
                    "doc": "Define the M threshold of percentile for training TMM. [default: 80]",
                    "id": "#rgt-thor.cwl/m_threshold"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--merge",
                        "position": 10
                    },
                    "doc": "Merge peaks which have a distance less than the estimated mean fragment size (recommended for histone data)",
                    "id": "#rgt-thor.cwl/merge_peaks"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--no-correction",
                        "position": 15
                    },
                    "doc": "Do not use multipe test correction for p-values (Benjamini/Hochberg)",
                    "id": "#rgt-thor.cwl/no_correction"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--no-gc-content",
                        "position": 23
                    },
                    "doc": "Do not normalize towards GC content",
                    "id": "#rgt-thor.cwl/no_gc_content"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--no-merge-bin",
                        "position": 11
                    },
                    "doc": "Merge the overlapping bin before filtering by p-value",
                    "id": "#rgt-thor.cwl/no_merge_bin"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--norm-regions",
                        "position": 24
                    },
                    "doc": "Restrict normalization to particular regions",
                    "id": "#rgt-thor.cwl/norm_regions_bed_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "float"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--factors-inputs",
                        "position": 18,
                        "itemSeparator": ","
                    },
                    "doc": "Normalization factors for input-DNA (comma separated list for each BAM file in config file).\nIf option is not chosen, estimate factors\n",
                    "id": "#rgt-thor.cwl/normalization_factor"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--name",
                        "position": 9
                    },
                    "doc": "Experiment's name and prefix for all files that are created",
                    "id": "#rgt-thor.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--poisson",
                        "position": 29
                    },
                    "doc": "Use binomial distribution as emmission",
                    "id": "#rgt-thor.cwl/poisson"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--pvalue",
                        "position": 16
                    },
                    "doc": "P-value cutoff for peak detection. Call only peaks with p-value lower than cutoff. [default: 0.1]",
                    "id": "#rgt-thor.cwl/pvalue_cutoff"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--par",
                        "position": 28
                    },
                    "doc": "Percentile for p-value postprocessing filter. [default: 1]",
                    "id": "#rgt-thor.cwl/pvalue_filter_percentile"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--regions",
                        "position": 20
                    },
                    "doc": "Define regions (BED format) to restrict the analysis, that is, where to train the HMM and search for DPs",
                    "id": "#rgt-thor.cwl/regions_bed_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--rmdup",
                        "position": 33
                    },
                    "doc": "Remove the duplicate reads",
                    "id": "#rgt-thor.cwl/remove_duplicates"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "float"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--scaling-factors",
                        "position": 19,
                        "itemSeparator": ","
                    },
                    "doc": "Scaling factor for each BAM file (not control input-DNA) as comma separated list for each BAM file in config file.\nIf option is not chosen, follow normalization strategy (TMM or HK approach) [default: none]\n",
                    "id": "#rgt-thor.cwl/scaling_factor"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\nadd_rep () {\n    echo \"$1\" >> \"$3\"\n    while IFS=',' read -ra REP; do\n        for i in \"${REP[@]}\"; do\n            echo $i >> \"$3\"\n        done\n    done <<< \"$2\"\n}\n> config.txt\nadd_rep \"#rep1\" \"$0\" config.txt\nadd_rep \"#rep2\" \"$1\" config.txt\necho \"#chrom_sizes\" >> config.txt\necho \"$2\" >> config.txt\nrgt-THOR config.txt \"${@:3}\"\n",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "Bash function to generate config.txt and run rgt-THOR",
                    "id": "#rgt-thor.cwl/script"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--single-strand",
                        "position": 30
                    },
                    "doc": "Allow single strand BAM file as input",
                    "id": "#rgt-thor.cwl/single_strand"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--step",
                        "position": 22
                    },
                    "doc": "Stepsize with which the window consecutively slides across the genome to create the signal. [default: 50]",
                    "id": "#rgt-thor.cwl/step_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--threshold",
                        "position": 26
                    },
                    "doc": "Minimum signal support for differential peaks to define training set as percentage (t_2, see paper). [default: 95]",
                    "id": "#rgt-thor.cwl/threshold"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*-s1-rep*.bw"
                    },
                    "id": "#rgt-thor.cwl/cond_1_bigwig_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "outputBinding": {
                        "glob": "*-s2-rep*.bw"
                    },
                    "id": "#rgt-thor.cwl/cond_2_bigwig_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*[!-uncor]-diffpeaks.bed"
                    },
                    "id": "#rgt-thor.cwl/diffpeaks_bed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*[!-uncor]-diffpeaks.narrowPeak"
                    },
                    "id": "#rgt-thor.cwl/diffpeaks_narrowpeak_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*-setup.info"
                    },
                    "id": "#rgt-thor.cwl/setup_info_file"
                },
                {
                    "type": "File",
                    "id": "#rgt-thor.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "thor_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#rgt-thor.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "thor_stdout.log"
                    }
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*-uncor-diffpeaks.bed"
                    },
                    "id": "#rgt-thor.cwl/uncor_diffpeaks_bed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*-uncor-diffpeaks.narrowPeak"
                    },
                    "id": "#rgt-thor.cwl/uncor_diffpeaks_narrowpeak_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "stderr": "thor_stderr.log",
            "stdout": "thor_stdout.log",
            "label": "THOR - differential peak calling of ChIP-seq signals with replicates",
            "doc": "Configuration file is autogenerated based on the bambai_pair_cond_1, bambai_pair_cond_2 and chrom_length_file inputs.\nThe following parameters in a configuration file are skipped: genome, inputs1, inputs2.\nThe following arguments are skipped: --report (tool fails to execute)\n",
            "id": "#rgt-thor.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#rgt-metadata.yaml",
                "http://schema.org/name": "RGT",
                "http://schema.org/about": "Regulatory Genomics Toolbox  is a python library and set of tools  for the integrative analysis of\nhigh throughput regulatory genomics data. This library has been used for implementation of several\ntools as ChIP-Seq differential peak callers (ODIN and THOR), DNase-Seq footprinting method (HINT)\nand the visualization tool RGT-Viz. It is implemented in a object oriented fashion in python\nincluding basic infrastructure for manipulation of genomic data. This project is developed and\nmaintained by Computational Biology and Bioinformatics Research Group, RWTH University Hostpital."
            },
            "http://schema.org/name": "THOR - differential peak calling of ChIP-seq signals with replicates",
            "http://schema.org/alternateName": "THOR is an HMM-based approach to detect and analyze differential peaks in two sets of ChIP-seq data from distinct biological conditions with replicates",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/rgt-thor.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\nrgt-THOR [options] CONFIG\n\nTHOR detects differential peaks in multiple ChIP-seq profiles associated\nwith two distinct biological conditions.\n\nCopyright (C) 2014-2016  Manuel Allhoff (allhoff@aices.rwth-aachen.de)\n\nThis program comes with ABSOLUTELY NO WARRANTY. This is free\nsoftware, and you are welcome to redistribute it under certain\nconditions. Please see LICENSE file for details.\n\nOptions:\n  -h, --help            show this help message and exit\n  -n NAME, --name=NAME  Experiment's name and prefix for all files that are\n                        created.\n  -m, --merge           Merge peaks which have a distance less than the\n                        estimated mean fragment size (recommended for histone\n                        data). [default: do not merge]\n  --no-merge-bin        Merge the overlapping bin before filtering by\n                        p-value.[default: Merging bins]\n  --housekeeping-genes=HOUSEKEEPING_GENES\n                        Define housekeeping genes (BED format) used for\n                        normalizing. [default: none]\n  --output-dir=OUTPUTDIR\n                        Store files in output directory. [default: none]\n  --report              Generate HTML report about experiment. [default:\n                        False]\n  --deadzones=DEADZONES\n                        Define blacklisted genomic regions avoided for\n                        analysis (BED format). [default: none]\n  --no-correction       Do not use multipe test correction for p-values\n                        (Benjamini/Hochberg). [default: False]\n  -p PCUTOFF, --pvalue=PCUTOFF\n                        P-value cutoff for peak detection. Call only peaks\n                        with p-value lower than cutoff. [default: 0.1]\n  --exts=EXTS           Read's extension size for BAM files (comma separated\n                        list for each BAM file in config file). If option is\n                        not chosen, estimate extension sizes. [default: none]\n  --factors-inputs=FACTORS_INPUTS\n                        Normalization factors for input-DNA (comma separated\n                        list for each BAM file in config file). If option is\n                        not chosen, estimate factors. [default: none]\n  --scaling-factors=SCALING_FACTORS_IP\n                        Scaling factor for each BAM file (not control input-\n                        DNA) as comma separated list for each BAM file in\n                        config file. If option is not chosen, follow\n                        normalization strategy (TMM or HK approach) [default:\n                        none]\n  --save-input          Save input-DNA file if available. [default: False]\n  --version             Show script's version.\n\n  Advanced options:\n    --regions=REGIONS   Define regions (BED format) to restrict the analysis,\n                        that is, where to train the HMM and search for DPs. It\n                        is faster, but less precise.\n    -b BINSIZE, --binsize=BINSIZE\n                        Size of underlying bins for creating the signal.\n                        [default: 100]\n    -s STEPSIZE, --step=STEPSIZE\n                        Stepsize with which the window consecutively slides\n                        across the genome to create the signal. [default: 50]\n    --debug             Output debug information. Warning: space consuming!\n                        [default: False]\n    --no-gc-content     Do not normalize towards GC content. [default: False]\n    --norm-regions=NORM_REGIONS\n                        Restrict normalization to particular regions (BED\n                        format). [default: none]\n    -f FOLDCHANGE, --foldchange=FOLDCHANGE\n                        Fold change parameter to define training set (t_1, see\n                        paper). [default: 1.6]\n    -t THRESHOLD, --threshold=THRESHOLD\n                        Minimum signal support for differential peaks to\n                        define training set as percentage (t_2, see paper).\n                        [default: 95]\n    --size=SIZE_TS      Number of bins the HMM's training set constists of.\n                        [default: 10000]\n    --par=PAR           Percentile for p-value postprocessing filter.\n                        [default: 1]\n    --poisson           Use binomial distribution as emmission. [default:\n                        False]\n    --single-strand     Allow single strand BAM file as input. [default:\n                        False]\n    --m_threshold=M_THRESHOLD\n                        Define the M threshold of percentile for training TMM.\n                        [default: 80]\n    --a_threshold=A_THRESHOLD\n                        Define the A threshold of percentile for training TMM.\n                        [default: 95]\n    --rmdup             Remove the duplicate reads [default: False]\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { return inputs.input_bed.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\".bb\"; };",
                        "var get_bed_type = function() { if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"narrowpeak\"){ return \"bed6+4\"; } else if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"broadpeak\"){ return \"bed6+3\"; } else { return null; } };",
                        "var get_bed_template = function() { if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"narrowpeak\"){ return \"narrowpeak.as\"; } else if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"broadpeak\"){ return \"broadpeak.as\"; } else { return null; } };"
                    ]
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "narrowpeak.as",
                            "entry": "table narrowPeak\n\"BED6+4 Peaks of signal enrichment based on pooled, normalized (interpreted) data.\"\n(\n  string  chrom;        \"Reference sequence chromosome or scaffold\"\n  uint    chromStart;   \"Start position in chromosome\"\n  uint    chromEnd;     \"End position in chromosome\"\n  string  name;\t        \"Name given to a region (preferably unique). Use . if no name is assigned\"\n  uint    score;        \"Indicates how dark the peak will be displayed in the browser (0-1000) \"\n  char[1] strand;       \"+ or - or . for unknown\"\n  float   signalValue;  \"Measurement of average enrichment for the region\"\n  float   pValue;       \"Statistical significance of signal value (-log10). Set to -1 if not used.\"\n  float   qValue;       \"Statistical significance with multiple-test correction applied (FDR -log10). Set to -1 if not used.\"\n  int     peak;         \"Point-source called for this peak; 0-based offset from chromStart. Set to -1 if no point-source called.\"\n)\n"
                        },
                        {
                            "entryname": "broadpeak.as",
                            "entry": "table broadPeak\n\"BED6+3 Peaks of signal enrichment based on pooled, normalized (interpreted) data.\"\n(\n  string  chrom;        \"Reference sequence chromosome or scaffold\"\n  uint    chromStart;   \"Start position in chromosome\"\n  uint    chromEnd;     \"End position in chromosome\"\n  string  name;\t        \"Name given to a region (preferably unique). Use . if no name is assigned.\"\n  uint    score;        \"Indicates how dark the peak will be displayed in the browser (0-1000)\"\n  char[1] strand;       \"+ or - or . for unknown\"\n  float   signalValue;  \"Measurement of average enrichment for the region\"\n  float   pValue;       \"Statistical significance of signal value (-log10). Set to -1 if not used.\"\n  float   qValue;       \"Statistical significance with multiple-test correction applied (FDR -log10). Set to -1 if not used.\"\n)\n"
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/ucscuserapps:v358"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-as=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return get_bed_template();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "For non-standard \"bedPlus\" fields put a definition of each field in a row in AutoSql format.\nBy default includes only three required BED fields: chrom, chromStart, chromEnd\n",
                    "id": "#ucsc-bedtobigbed.cwl/bed_template"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-type=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return get_bed_type();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Type of BED file in a form of bedN[+[P]]. By default bed3 to three required BED fields\n",
                    "id": "#ucsc-bedtobigbed.cwl/bed_type"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-blockSize=",
                        "separate": false
                    },
                    "doc": "Number of items to bundle in r-tree.  Default 256\n",
                    "id": "#ucsc-bedtobigbed.cwl/block_size"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 21
                    },
                    "doc": "Chromosome length files\n",
                    "id": "#ucsc-bedtobigbed.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-extraIndex=",
                        "separate": false
                    },
                    "doc": "Makes an index on each field in a comma separated list extraIndex=name and extraIndex=name,id are commonly used\n",
                    "id": "#ucsc-bedtobigbed.cwl/extra_index"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 20
                    },
                    "doc": "Input BED file\n",
                    "id": "#ucsc-bedtobigbed.cwl/input_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-itemsPerSlot=",
                        "separate": false
                    },
                    "doc": "Number of data points bundled at lowest level. Default 512\n",
                    "id": "#ucsc-bedtobigbed.cwl/items_per_slot"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 22,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Output filename\n",
                    "id": "#ucsc-bedtobigbed.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-sizesIs2Bit=",
                        "separate": false
                    },
                    "doc": "If set, the chrom.sizes file is assumed to be a 2bit file\n",
                    "id": "#ucsc-bedtobigbed.cwl/size_2bit"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-tab"
                    },
                    "doc": "If set, expect fields to be tab separated, normally expects white space separator\n",
                    "id": "#ucsc-bedtobigbed.cwl/tab_sep"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-unc"
                    },
                    "doc": "If set, do not use compression\n",
                    "id": "#ucsc-bedtobigbed.cwl/unc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename();\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#ucsc-bedtobigbed.cwl/bigbed_file"
                }
            ],
            "baseCommand": [
                "bedToBigBed"
            ],
            "doc": "Tool converts bed file to bigBed\n\nBefore running `baseCommand` the following files are created in Docker working directory (using\n`InitialWorkDirRequirement`):\n`narrowpeak.as` - default BED file structure template for ENCODE narrowPeak format\n`broadpeak.as`  - default BED file structure template for ENCODE broadPeak format\n\n`default_output_filename` function returns default output file name based on `input_bed` basename with `*.bb`\nextension if `output_filename` is not provided.\n\n`get_bed_type` function returns default BED file type if `bed_type` is not provided. Depending on `input_bed` file\nextension the following values are returned:\n  `*.narrowpeak`  -->   bed6+4\n  `*.broadpeak`   -->   bed6+3\n   else           -->   null (`bedToBigBed` will use its own default value)\n\n`get_bed_template` function returns default BED file template if `bed_template` is not provided. Depending on\n`input_bed` file extension the following values are returned:\n    `*.narrowpeak`  -->   narrowpeak.as (previously staged into Docker working directory)\n    `*.broadpeak`   -->   broadpeak.as (previously staged into Docker working directory)\n     else           -->   null (`bedToBigBed` will use its own default value)\n",
            "id": "#ucsc-bedtobigbed.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#ucsc-metadata.yaml",
                "http://schema.org/name": "UCSC userApps",
                "http://schema.org/about": "UCSC genome browser bioinformatic utilities\n",
                "http://schema.org/url": "https://genome.ucsc.edu/util.html",
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v358",
                    "http://schema.org/applicationCategory": "commandline tool",
                    "http://schema.org/downloadURL": "http://hgdownload.cse.ucsc.edu/admin/exe/userApps.v358.src.tgz"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ]
            },
            "http://schema.org/name": "ucsc-bedtobigbed",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/ucsc-bedtobigbed.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage:\n   bedToBigBed in.bed chrom.sizes out.bb\nWhere in.bed is in one of the ascii bed formats, but not including track lines\nand chrom.sizes is a two-column file/URL: <chromosome name> <size in bases>\nand out.bb is the output indexed big bed file.\nIf the assembly <db> is hosted by UCSC, chrom.sizes can be a URL like\n  http://hgdownload.cse.ucsc.edu/goldenPath/<db>/bigZips/<db>.chrom.sizes\nor you may use the script fetchChromSizes to download the chrom.sizes file.\nIf not hosted by UCSC, a chrom.sizes file can be generated by running\ntwoBitInfo on the assembly .2bit file.\nThe in.bed file must be sorted by chromosome,start,\n  to sort a bed file, use the unix sort command:\n     sort -k1,1 -k2,2n unsorted.bed > sorted.bed\nSorting must be set to skip Unicode mapping (LC_COLLATE=C).\n\noptions:\n   -type=bedN[+[P]] :\n                      N is between 3 and 15,\n                      optional (+) if extra \"bedPlus\" fields,\n                      optional P specifies the number of extra fields. Not required, but preferred.\n                      Examples: -type=bed6 or -type=bed6+ or -type=bed6+3\n                      (see http://genome.ucsc.edu/FAQ/FAQformat.html#format1)\n   -as=fields.as - If you have non-standard \"bedPlus\" fields, it's great to put a definition\n                   of each field in a row in AutoSql format here.\n   -blockSize=N - Number of items to bundle in r-tree.  Default 256\n   -itemsPerSlot=N - Number of data points bundled at lowest level. Default 512\n   -unc - If set, do not use compression.\n   -tab - If set, expect fields to be tab separated, normally\n           expects white space separator.\n   -extraIndex=fieldList - If set, make an index on each field in a comma separated list\n           extraIndex=name and extraIndex=name,id are commonly used.\n   -sizesIs2Bit  -- If set, the chrom.sizes file is assumed to be a 2bit file.\n   -udcDir=/path/to/udcCacheDir  -- sets the UDC cache dir for caching of remote files.\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "first_biological_condition": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "second_biological_condition": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "genome_indices": [
                    "genome-indices.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "condition_1",
                    "label": "Name for condition 1",
                    "doc": "Name to be displayed for condition 1",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/alias_cond_1"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "condition_2",
                    "label": "Name for condition 2",
                    "doc": "Name to be displayed for condition 2",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/alias_cond_2"
                },
                {
                    "type": "File",
                    "label": "Genome annotation",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Genome annotation file in TSV format",
                    "sd:upstreamSource": "genome_indices/annotation",
                    "id": "#main/annotation_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "format": "http://edamontology.org/format_2572",
                    "label": "Biological condition 1",
                    "doc": "Coordinate sorted BAM alignment and index BAI files for the first biological condition",
                    "sd:upstreamSource": "first_biological_condition/bambai_pair",
                    "sd:localLabel": true,
                    "id": "#main/bambai_pair_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "format": "http://edamontology.org/format_2572",
                    "label": "Biological condition 2",
                    "doc": "Coordinate sorted BAM alignment and index BAI files for the second biological condition",
                    "sd:upstreamSource": "second_biological_condition/bambai_pair",
                    "sd:localLabel": true,
                    "id": "#main/bambai_pair_cond_2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 100,
                    "label": "Size of underlying bins for creating the signal",
                    "doc": "Size of underlying bins for creating the signal",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/bin_size"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Chromosome length file",
                    "doc": "Chromosome length file",
                    "sd:upstreamSource": "genome_indices/chrom_length",
                    "id": "#main/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3003",
                    "label": "Dead zones file",
                    "doc": "Define blacklisted genomic regions avoided for analysis",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/deadzones_bed_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "label": "Comma-separated list of read extension sizes (provide value for every sample)",
                    "doc": "Read's extension size for BAM files (comma separated list for each BAM file in config file).\nIf option is not chosen, estimate extension sizes\n",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/extension_size"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3003",
                    "label": "Housekeeping genes file",
                    "doc": "Define housekeeping genes (BED format) used for normalizing",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/housekeeping_genes_bed_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "label": "Merge peaks closer than fragment size",
                    "doc": "Merge peaks which have a distance less than the estimated mean fragment size (recommended for histone data)",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/merge_peaks"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "label": "P-value cutoff for peak detection",
                    "doc": "P-value cutoff for peak detection. Call only peaks with p-value lower than cutoff. [default: 0.1]",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/pvalue_cutoff"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Remove the duplicate reads",
                    "doc": "Remove the duplicate reads",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/remove_duplicates"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3006",
                    "label": "First biological condition ChIP-seq signals",
                    "doc": "Postprocessed ChIP-seq signals from the first biological condition samples",
                    "outputSource": "#main/thor/cond_1_bigwig_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/cond_1_bigwig_file/igvbrowser",
                                "type": "wig",
                                "name": "#main/cond_1_bigwig_file/Biological condition 1",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/cond_1_bigwig_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3006",
                    "label": "Second biological condition ChIP-seq signals",
                    "doc": "Postprocessed ChIP-seq signals from the second biological condition samples",
                    "outputSource": "#main/thor/cond_2_bigwig_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/cond_2_bigwig_file/igvbrowser",
                                "type": "wig",
                                "name": "#main/cond_2_bigwig_file/Biological condition 2",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/cond_2_bigwig_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "Estimated differential peaks with assigned genes",
                    "doc": "File contains nearest gene information for the differential peaks BED file generated by rgt-THOR",
                    "outputSource": "#main/restore_columns/output_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Differential Peak Calling",
                                "Title": "Differential Peaks rgt-THOR Results"
                            }
                        }
                    ],
                    "id": "#main/diffpeaks_annotated_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3004",
                    "label": "Estimated differential peaks",
                    "doc": "Estimated differential peaks, bigBed",
                    "outputSource": "#main/bed_to_bigbed/bigbed_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/diffpeaks_bed_file/igvbrowser",
                                "type": "annotation",
                                "format": "#main/diffpeaks_bed_file/bigbed",
                                "name": "#main/diffpeaks_bed_file/Differential peaks",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/diffpeaks_bed_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "rgt-THOR stderr log",
                    "doc": "rgt-THOR stderr log",
                    "outputSource": "#main/thor/stderr_log",
                    "id": "#main/thor_stderr_log"
                }
            ],
            "steps": [
                {
                    "run": "#iaintersect.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/assign_genes/annotation_filename"
                        },
                        {
                            "source": "#main/filter_columns/output_file",
                            "id": "#main/assign_genes/input_filename"
                        },
                        {
                            "default": 1000,
                            "id": "#main/assign_genes/promoter_bp"
                        }
                    ],
                    "out": [
                        "#main/assign_genes/result_file"
                    ],
                    "id": "#main/assign_genes"
                },
                {
                    "run": "#ucsc-bedtobigbed.cwl",
                    "in": [
                        {
                            "default": "bed4+7",
                            "id": "#main/bed_to_bigbed/bed_type"
                        },
                        {
                            "source": "#main/chrom_length_file",
                            "id": "#main/bed_to_bigbed/chrom_length_file"
                        },
                        {
                            "source": "#main/sort_bed/sorted_file",
                            "id": "#main/bed_to_bigbed/input_bed"
                        },
                        {
                            "source": "#main/sort_bed/sorted_file",
                            "valueFrom": "$(self.basename + \".bigBed\")",
                            "id": "#main/bed_to_bigbed/output_filename"
                        }
                    ],
                    "out": [
                        "#main/bed_to_bigbed/bigbed_file"
                    ],
                    "id": "#main/bed_to_bigbed"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/thor/diffpeaks_bed_file",
                            "id": "#main/filter_columns/input_file"
                        },
                        {
                            "default": "cat $0 | awk 'BEGIN {print \"chr\\tstart\\tend\\tlength\\tabs_summit\\tpileup\\t-log10(pvalue)\\tfold_enrichment\\t-log10(qvalue)\\tname\"} {print $1\"\\t\"$2\"\\t\"$3\"\\t\"$3-$2+1\"\\t0\\t\"NR\"\\t0\\t0\\t0\\t0\"}' > `basename $0`\n",
                            "id": "#main/filter_columns/script"
                        }
                    ],
                    "out": [
                        "#main/filter_columns/output_file"
                    ],
                    "id": "#main/filter_columns"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/assign_genes/result_file",
                                "#main/thor/diffpeaks_bed_file"
                            ],
                            "id": "#main/restore_columns/input_file"
                        },
                        {
                            "source": [
                                "#main/alias_cond_1",
                                "#main/alias_cond_2"
                            ],
                            "id": "#main/restore_columns/param"
                        },
                        {
                            "default": "NAME_1=$2\nNAME_2=$3\ncat $0 | grep -v \"start\" | sort -k 11n > sorted_iaintersect_result.tsv\ncat $1 | tr \";\" \"\\t\" > thor_result.tsv\necho -e \"refseq_id\\tgene_id\\ttxStart\\ttxEnd\\tstrand\\tchrom\\tstart\\tend\\tlength\\tregion\\tname\\tscore\\tcondition\\tcolor\\t${NAME_1}_counts\\t${NAME_2}_counts\\t-log10(pvalue)\" > `basename $0`;\ncat sorted_iaintersect_result.tsv | paste - thor_result.tsv | cut -f 1-9,15,19-21,24,26-28 >> `basename $0`\nrm sorted_iaintersect_result.tsv thor_result.tsv\n",
                            "id": "#main/restore_columns/script"
                        }
                    ],
                    "out": [
                        "#main/restore_columns/output_file"
                    ],
                    "id": "#main/restore_columns"
                },
                {
                    "run": "#linux-sort.cwl",
                    "in": [
                        {
                            "default": [
                                "1,1",
                                "2,2n"
                            ],
                            "id": "#main/sort_bed/key"
                        },
                        {
                            "source": "#main/thor/diffpeaks_bed_file",
                            "id": "#main/sort_bed/unsorted_file"
                        }
                    ],
                    "out": [
                        "#main/sort_bed/sorted_file"
                    ],
                    "id": "#main/sort_bed"
                },
                {
                    "run": "#rgt-thor.cwl",
                    "in": [
                        {
                            "source": "#main/bambai_pair_cond_1",
                            "id": "#main/thor/bambai_pair_cond_1"
                        },
                        {
                            "source": "#main/bambai_pair_cond_2",
                            "id": "#main/thor/bambai_pair_cond_2"
                        },
                        {
                            "source": "#main/bin_size",
                            "id": "#main/thor/bin_size"
                        },
                        {
                            "source": "#main/chrom_length_file",
                            "id": "#main/thor/chrom_length_file"
                        },
                        {
                            "source": "#main/deadzones_bed_file",
                            "id": "#main/thor/deadzones_bed_file"
                        },
                        {
                            "source": "#main/extension_size",
                            "id": "#main/thor/extension_size"
                        },
                        {
                            "source": "#main/housekeeping_genes_bed_file",
                            "id": "#main/thor/housekeeping_genes_bed_file"
                        },
                        {
                            "source": "#main/merge_peaks",
                            "id": "#main/thor/merge_peaks"
                        },
                        {
                            "source": "#main/pvalue_cutoff",
                            "id": "#main/thor/pvalue_cutoff"
                        },
                        {
                            "source": "#main/remove_duplicates",
                            "id": "#main/thor/remove_duplicates"
                        }
                    ],
                    "out": [
                        "#main/thor/diffpeaks_bed_file",
                        "#main/thor/cond_1_bigwig_file",
                        "#main/thor/cond_2_bigwig_file",
                        "#main/thor/stderr_log"
                    ],
                    "id": "#main/thor"
                }
            ],
            "label": "THOR - differential peak calling of ChIP-seq signals with replicates",
            "doc": "What is THOR?\n--------------\n\nTHOR is an HMM-based approach to detect and analyze differential peaks in two sets of ChIP-seq data\nfrom distinct biological conditions with replicates. THOR performs genomic signal processing, peak\ncalling and p-value calculation in an integrated framework.\n\nFor more information please refer to:\n-------------------------------------\n\nAllhoff, M., Sere K., Freitas, J., Zenke, M., Costa, I.G. (2016), Differential Peak Calling of ChIP-seq\nSignals with Replicates with THOR, Nucleic Acids Research, epub gkw680.\n",
            "id": "#main",
            "http://schema.org/name": "THOR - differential peak calling of ChIP-seq signals with replicates",
            "http://schema.org/alternateName": "THOR is an HMM-based approach to detect and analyze differential peaks in two sets of ChIP-seq data from distinct biological conditions with replicates",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/rgt-thor.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
